@@ -181,7 +181,10 @@ class GBMFitter:
 
         if library == 'XGB':
             if categorical:
-                X_train = ce.one_hot.OneHotEncoder(cols=categorical, drop_invariant=True).fit_transform(X_train)
+                train_all = pd.concat([X_train,X_val])
+                encoder = ce.one_hot.OneHotEncoder(cols=categorical, drop_invariant=True).fit(train_all)
+                X_train = encoder.transform(X_train)
+                X_val = encoder.transform(X_val)
 
             m = xgb.train(params=model_data['params'],
                           dtrain=xgb.DMatrix(X_train, y_train),
