@@ -522,10 +522,9 @@ class BaseOptimizer(ABC):
             dict that contains the best params and the best number of iterations
         """
 
-
         # Build objective function
         if objective is None:
-            objective = self.get_obj(X_train, y_train, cat_features=cat_features, n_folds=n_folds, folds=folds,  max_rounds=max_rounds, early_stopping=early_stopping)
+            objective = self.get_obj(X_train, y_train, cat_features=cat_features, n_folds=n_folds, folds=folds,  max_rounds=max_rounds, early_stopping=early_stopping, verbose=verbose)
 
         # Run the optimization
         self.trials = Trials()
